@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Engine/POE.pm 6454 2007-04-10T02:44:06.724398Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Engine/POE.pm 6457 2007-04-11T03:32:16.482599Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -90,7 +90,7 @@ sub session_loop
         return;
     }
 
-    $self->dispatch_requests($c);
+    $c->dispatch_requests();
 
     my $alarm_id = $self->loop_alarm;
     if (! $alarm_id) {
@@ -102,17 +102,6 @@ sub session_loop
     }
 }
 
-sub dispatch_requests
-{
-    my ($self, $c) = @_;
-
-    if ($c->has_requests) {
-        foreach my $request ( $c->get_requests() ) {
-            $self->send_request($c, $request);
-        }
-    }
-}
-
 # XXX - this is not a POE state. hmmm??
 sub send_request
 {
@@ -189,10 +178,6 @@ sets up the engine.
 Instantiates a PoCo::Client::HTTP session and a main session that handles the
 main control.
 
-=head2 dispatch_requests($c)
-
-Retrieves pending requests from Gungho and dispatches them
-
 =head2 send_request($request)
 
 Sends a request to the http client
